// SPDX-License-Identifier: GPL-3.0-or-later
// Copyright 2021 Juan Palacios <jpalaciosdev@gmail.com>

#pragma once

#include <string_view>

namespace AMD::JunctionTemp {

static constexpr std::string_view ItemID{"AMD_GPU_JUNCTION_TEMP"};

} // namespace AMD::JunctionTemp
